;; $Id: dbcompon.dsl 0.1 1997/07/31 14:51:33 nwalsh Exp $

;; ============================= COMPONENTS =============================
;;
;; in docbook, components are containers at the chapter/appendix level

(define ($x-component$)
  (make element gi: "DIV"
	attributes: (list
		     (list "CLASS" (gi)))
	(process-children-trim)))

(define ($component$)
  (let ((chap-num (child-number (current-node))))
    (make entity
      system-id: (html-file)
      (make document-type
	name: "HTML"
	public-id: %html-pubid%)
      (make element gi: "HTML"
	    (make element gi: "HEAD"
		  (make element gi: "TITLE"
			(with-mode admon-caption-mode
			  (process-first-descendant "TITLE"))))
	    (make element gi: "BODY" 
		  attributes: %body-attr%
		  (header-navigation (current-node))
		  (process-children)
		  (footer-navigation (current-node)))))))

(define ($comptitle$)
  (make sequence
    (make element gi: "H1"
	  (literal
	   (cond ((have-ancestor? "CHAPTER")
		  (CHAP-APP-HEAD-LABEL "CHAPTER"))
		 ((have-ancestor? "APPENDIX")
		  (CHAP-APP-HEAD-LABEL "APPENDIX"))
		 (else "")))
	  (process-children-trim))
    (if %generate-chapter-toc%
	($chapter-toc$)
	(empty-sosofo))))

(define ($chapter-toc$)
  ;; Called by the TITLE element so that it can come after the TITLE
  (let* ((p (parent (current-node)))
	 (sects (if (equal? (gi p) "REFERENCE")
		   (select-elements (children p) "REFENTRY")
		   (select-elements (children p) "SECT1"))))
    (make element gi: "DIV"
	  attributes: (list
		       (list "CLASS" "CHAPTER-TOC"))
	  (make element gi: "P"
		(make element gi: "B"
		      (literal "Contents:"))
		(make empty-element gi: "BR")
		(with-mode chapter-toc-mode
		  (process-node-list sects))))))

(mode chapter-toc-mode
  (element SECT1
    (make sequence
      (if (first-sibling?)
	  (process-first-descendant "TITLE")
	  (make element gi: "A"
		attributes: (list
			     (list "HREF" (href-to (current-node))))
		(process-first-descendant "TITLE")))
      (make empty-element gi: "BR")))

  (element REFENTRY
    (make element gi: "A"
	  attributes: (list
		       (list "HREF" (href-to (current-node))))
	  (process-first-descendant "REFENTRYTITLE")
	  (make empty-element gi: "BR")))
  
  (element TITLE
    (process-children-trim))

  (element REFENTRYTITLE
    (process-children-trim)))

(define (CHAP-APP-HEAD-LABEL chap-or-app)
  (let ((label
	 (attribute-string "label" (ancestor chap-or-app))))
    (if (or label %chap-app-running-head-autolabel%)
	(string-append 
	 (gentext-element-name-space chap-or-app)
	 (if (or (not label) (equal? label "auto"))
	     (format-number
	      (element-number (ancestor chap-or-app))
	      (if (equal? chap-or-app "CHAPTER") "1" "A"))
	     label)
	 (gentext-label-title-sep chap-or-app))
	"")))

(element APPENDIX ($component$))
(element (APPENDIX TITLE) ($comptitle$))
(element CHAPTER ($component$))
(element (CHAPTER TITLE) ($comptitle$))
(element PREFACE ($component$))
(element (PREFACE TITLE) ($comptitle$))
